Learn R Programming

bnspatial (version 0.9)

evidence: Evidence from extracted spatial inputs.

Description

A matrix. The collection of available spatial data (see above) as extracted from each location (i.e. cell) in the catchment, where the latter is represented by the raster object currentLU. Each value from the spatial data was discretized through dataDiscretize or bulkDiscretize functions, then assigned to the corresponding state from the Bayesian network (LandUseChange).

Arguments