LUclasses: Lookup list, linking input spatial data and the Bayesian network
Description
A list with the classification of input spatial data (its corresponding states and values).
The list is formatted accordingly to bnspatial functions requirement and as returned by
functions importClasses and setClasses.