## Make a mask from a group of input layers:
data(ConwyData)
network <- LandUseChange
spatialData <- c(currentLU, slope, status)
m <- aoi(spatialData)
m
## Plot mask
library(raster)
m <- aoi(currentLU)
plot(m)
## Make mask from a subset of values and plot
m <- aoi(currentLU, mskSub=c(2,3))
plot(m)
## Return coordinates of valid mask locations
coord <- aoi(currentLU, xy=TRUE)
head(coord)
Run the code above in your browser using DataLab